==> knative-model-4.12.0-sources.jar: annotations/io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaSourceStatusBuilder.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class KafkaSourceStatusBuilder extends KafkaSourceStatusFluentImpl<KafkaSourceStatusBuilder> implements VisitableBuilder<KafkaSourceStatus,KafkaSourceStatusBuilder> {

    KafkaSourceStatusFluent<?> fluent;
    Boolean validationEnabled;

    public KafkaSourceStatusBuilder() { 
        this(true);
    }


    public KafkaSourceStatusBuilder(Boolean validationEnabled) { 
        this(new KafkaSourceStatus(), validationEnabled);
    }


    public KafkaSourceStatusBuilder(KafkaSourceStatusFluent<?> fluent) { 
        this(fluent, true);
    }


    public KafkaSourceStatusBuilder(KafkaSourceStatusFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new KafkaSourceStatus(), validationEnabled);
    }


    public KafkaSourceStatusBuilder(KafkaSourceStatusFluent<?> fluent,KafkaSourceStatus instance) { 
        this(fluent, instance, true);
    }


    public KafkaSourceStatusBuilder(KafkaSourceStatusFluent<?> fluent,KafkaSourceStatus instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withAnnotations(instance.getAnnotations()); 
        fluent.withCeAttributes(instance.getCeAttributes()); 
        fluent.withConditions(instance.getConditions()); 
        fluent.withObservedGeneration(instance.getObservedGeneration()); 
        fluent.withSinkUri(instance.getSinkUri()); 
        this.validationEnabled = validationEnabled; 
    }


    public KafkaSourceStatusBuilder(KafkaSourceStatus instance) { 
        this(instance,true);
    }


    public KafkaSourceStatusBuilder(KafkaSourceStatus instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withAnnotations(instance.getAnnotations()); 
        this.withCeAttributes(instance.getCeAttributes()); 
        this.withConditions(instance.getConditions()); 
        this.withObservedGeneration(instance.getObservedGeneration()); 
        this.withSinkUri(instance.getSinkUri()); 
        this.validationEnabled = validationEnabled; 
    }


    public KafkaSourceStatus build() {
        KafkaSourceStatus buildable = new KafkaSourceStatus(fluent.getAnnotations(),fluent.getCeAttributes(),fluent.getConditions(),fluent.getObservedGeneration(),fluent.getSinkUri());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        KafkaSourceStatusBuilder that = (KafkaSourceStatusBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.1.2-sources.jar: annotations/io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaSourceStatusBuilder.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class KafkaSourceStatusBuilder extends KafkaSourceStatusFluentImpl<KafkaSourceStatusBuilder> implements VisitableBuilder<KafkaSourceStatus,KafkaSourceStatusBuilder> {

    KafkaSourceStatusFluent<?> fluent;
    Boolean validationEnabled;

    public KafkaSourceStatusBuilder() {
        this(true);
    }

    public KafkaSourceStatusBuilder(Boolean validationEnabled) {
        this(new KafkaSourceStatus(), validationEnabled);
    }

    public KafkaSourceStatusBuilder(KafkaSourceStatusFluent<?> fluent) {
        this(fluent, true);
    }

    public KafkaSourceStatusBuilder(KafkaSourceStatusFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new KafkaSourceStatus(), validationEnabled);
    }

    public KafkaSourceStatusBuilder(KafkaSourceStatusFluent<?> fluent,KafkaSourceStatus instance) {
        this(fluent, instance, true);
    }

    public KafkaSourceStatusBuilder(KafkaSourceStatusFluent<?> fluent,KafkaSourceStatus instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAnnotations(instance.getAnnotations()); 
        fluent.withCeAttributes(instance.getCeAttributes()); 
        fluent.withConditions(instance.getConditions()); 
        fluent.withObservedGeneration(instance.getObservedGeneration()); 
        fluent.withSinkUri(instance.getSinkUri()); 
        this.validationEnabled = validationEnabled; 
    }

    public KafkaSourceStatusBuilder(KafkaSourceStatus instance) {
        this(instance,true);
    }

    public KafkaSourceStatusBuilder(KafkaSourceStatus instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withAnnotations(instance.getAnnotations()); 
        this.withCeAttributes(instance.getCeAttributes()); 
        this.withConditions(instance.getConditions()); 
        this.withObservedGeneration(instance.getObservedGeneration()); 
        this.withSinkUri(instance.getSinkUri()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.EditableKafkaSourceStatus build() {
        EditableKafkaSourceStatus buildable = new EditableKafkaSourceStatus(fluent.getAnnotations(),fluent.getCeAttributes(),fluent.getConditions(),fluent.getObservedGeneration(),fluent.getSinkUri());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        KafkaSourceStatusBuilder that = (KafkaSourceStatusBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
